==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-config/lxqt-config-brightness/lxqt-config-brightness_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../../../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Настройки яркости</translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки подсветки и яркости:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Используйте клавиши стрелок для изменения настроек..&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.ui" line="35"/>
        <source>Require confirmation after settings change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.cpp" line="68"/>
        <source>Brightness settings changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.cpp" line="69"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../../../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вывод:&lt;/b&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.13.0.orig.tar.xz: lxqt-l10n-0.13.0/lxqt-config/lxqt-config-brightness/lxqt-config-brightness_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../../../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Настройки яркости</translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.ui" line="25"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Use arrow keys to change settings.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Настройки подсветки и яркости:&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Используйте клавиши стрелок для изменения настроек..&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.ui" line="35"/>
        <source>Require confirmation after settings change</source>
        <translation>Требовать подтверждения после изменения настроек</translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.cpp" line="68"/>
        <source>Brightness settings changed</source>
        <translation>Настройки яркости изменены</translation>
    </message>
    <message>
        <location filename="../../../brightnesssettings.cpp" line="69"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Требуется подтверждение. Настройки правильные?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../../../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Вывод:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../../outputwidget.ui" line="67"/>
        <source>Right click to reset</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
